#line 1 "assembler/intel-gen4asm.p/lex.c"

#line 3 "assembler/intel-gen4asm.p/lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 243
#define YY_END_OF_BUFFER 244
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[679] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  244,  242,  240,  241,  242,  102,
      103,  114,  112,  110,  113,  111,  115,  238,  238,  116,
      101,  104,  117,  105,  236,  165,  236,  157,  236,  167,
      142,  236,  236,  236,  236,  236,  122,  236,  236,  236,
      142,  236,  236,  236,  171,  161,  236,  108,  109,  106,
      107,    8,    9,    8,    8,   17,  243,   16,   13,   14,
       15,   11,  243,  154,  133,  134,  131,  135,  130,  132,
      141,  140,  139,  136,  137,  138,  240,    0,    0,    0,
        0,    0,    0,    0,  226,  229,    0,  231,    0,  234,

      233,    0,  235,  225,    6,    0,    0,  238,    0,  166,
      158,  168,    0,  172,  162,  120,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,   77,  236,  236,  236,  236,  236,
      236,  128,  128,  128,  236,  236,  129,  236,  236,   65,
      236,  236,  145,  236,  236,  236,  236,  236,  236,  121,
      236,  236,  236,  236,  236,  236,  127,  127,  236,  236,
       53,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      163,  155,  236,  236,  159,  169,  236,  236,  236,  236,

      236,    7,   11,   11,    0,  131,  140,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  230,    0,  232,
      228,  227,    0,    0,    0,    1,    1,  239,  237,  164,
      156,  160,  170,  236,   49,  236,  236,  236,   52,   57,
      236,   48,  236,   33,  236,  236,   82,   81,  236,  236,
      236,  236,   58,  236,  236,  208,  143,   94,  236,   46,
       45,   43,   44,  236,  236,  236,  236,  200,  203,  236,
      236,   29,   30,   20,  236,  236,   66,  236,  152,  236,
      201,  236,  236,  236,  153,  202,   32,   26,   38,   31,
      236,  236,  236,   19,  236,  124,  236,  236,   37,    0,

      236,  236,   63,   25,  236,   83,   75,  206,  236,  236,
       80,  236,  236,  205,  236,  236,  236,  236,   51,  236,
       56,   55,  236,  207,  236,  144,  236,  236,  236,  236,
      236,  236,   91,  236,   93,  236,  236,  236,   54,   12,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  187,  237,  119,  236,   50,  236,  236,
      236,  236,  182,   34,   35,  236,  236,   79,   47,  236,
       59,  236,   70,  236,  236,  236,   68,  236,  236,  236,
      236,   71,  236,  150,  236,  236,  236,   64,   40,  236,
      151,   39,  236,   86,   84,  236,  236,  125,  126,  236,

      236,   18,   73,   89,   85,   22,   23,   21,   24,   41,
      236,  236,  236,  236,   61,  236,  236,  204,  236,   60,
      236,  236,  236,  186,   97,   76,  236,  236,    0,    0,
        0,   10,  118,    0,    0,    0,    0,  216,    0,    0,
        0,    0,  215,    0,    0,    0,    0,    0,    0,  236,
      236,  236,  146,  236,   36,   69,  149,  236,  191,  236,
      236,  236,   78,  236,  236,  236,  147,  236,  236,  236,
      148,  123,  236,   74,   72,  236,  236,   42,  236,  236,
      236,   62,  236,  236,  236,  236,  236,  236,   67,   90,
      175,    0,    0,   10,    0,  218,  220,  222,    0,  217,

      219,  221,    0,    4,    4,    0,    0,    0,    0,    0,
        0,  236,  188,  236,  193,  236,  236,  236,  236,  236,
      236,  236,  236,  210,  236,  211,  236,  236,  236,  197,
      236,  214,  236,  213,  209,  236,  192,  236,  236,    0,
        0,    0,  224,  223,    0,    0,    0,    0,    0,    0,
      236,  189,  236,  236,  236,  236,  236,  236,   27,   28,
       88,  236,  236,  236,  194,  195,   87,  190,  236,  236,
      236,    0,    0,  173,  181,    0,    0,    0,    0,    2,
        2,    0,  236,   96,  236,   98,  236,  236,  236,  236,
      236,  236,  236,  236,  236,    0,    0,    0,    0,    0,

        0,  199,  236,   95,  185,  236,  212,  236,  236,  184,
      236,   99,  176,    0,    0,    0,    0,    5,    5,    0,
        0,  198,  236,  100,  236,  236,    0,    0,    0,    0,
        0,  183,  236,  236,  174,    0,    0,    0,    3,    3,
        0,    0,  196,  236,    0,    0,    0,    0,  236,    0,
        0,    0,    0,   92,    0,    0,    0,    0,    0,    0,
        0,  178,    0,    0,    0,    0,    0,  177,    0,    0,
        0,    0,    0,    0,    0,  180,  179,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    7,    1,    1,    1,    1,    8,
        9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
       19,   20,   21,   22,   21,   23,   21,   24,   25,   26,
       27,   28,    1,    1,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
       45,   46,   47,   48,   49,   50,   51,   52,   53,   54,
       55,    1,   56,    1,   57,    1,   58,   59,   60,   61,

       62,   63,   64,   65,   66,   67,   68,   69,   70,   71,
       72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
       82,   83,   84,    1,   85,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[86] =
    {   0,
        1,    1,    1,    1,    1,    2,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    3,    3,    3,
        3,    3,    3,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    1,    1,    4,    3,    3,    3,
        3,    3,    3,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    1,    1
    } ;

static const flex_int16_t yy_base[693] =
    {   0,
        0,    0,   83,   85,   87,   91,   80,   88,  598,  593,
      172,  198,  224,  305,  584, 1695,  110, 1695,   77,   63,
     1695, 1695, 1695, 1695,  106,  360,  103,  214,  133,  220,
     1695, 1695, 1695, 1695,  428,  102,  243,  288,  216,  321,
      352,  101,  420,   91,    0,  465,  533,  547,   87,  423,
      610,  658,  348,  542,  233,  438,   91, 1695, 1695, 1695,
     1695, 1695, 1695, 1695,  527, 1695, 1695, 1695, 1695, 1695,
     1695,  504,    0, 1695, 1695, 1695,  186, 1695, 1695, 1695,
     1695,  618, 1695, 1695, 1695, 1695,  114,  479,   98,  107,
      642,  211,  115,  149,  154,  228,  229,  230,  300, 1695,

      231,  236, 1695, 1695, 1695,  175,  723,  733,    0, 1695,
     1695, 1695,  562,  282, 1695,  741,    0,  288,  288,  310,
      305,  304,  307,  347,  362,  351,  419,  483,  364,  368,
      413,  536,  749,  360,    0,  510,  363,  524,  380,  405,
      414,    0,  516,  518,  545,  501,  757,  510,  555,  581,
      620,  597,    0,  602,  606,  622,  618,  610,  623,  767,
      760,  635,  620,  638,  777,  633,  796,  806,  798,  645,
        0,  646,  657,  643,  802,  659,  661,  660,  800,  677,
      803,  807,  798,  798,  867,  818,  812,  805,  823,  820,
        0,    0,  835,  833,    0,    0,  834,  854,  855,  860,

      853, 1695,  512,  895,  494,  885,  913,  866,  868,  886,
      880,  876,  884,  872,  905,  909,  909, 1695,  896, 1695,
     1695, 1695,  909,  897,  177, 1695,  235,  939,    0, 1695,
     1695, 1695, 1695,  959,  932,  929,  922,  920,    0,    0,
      927,    0,  950,    0,  231,  951,    0,    0,  956,  946,
      939,  941,  947,  946,  943,    0,  982,    0,  966,    0,
        0,    0,    0,  960,  966,  975,  972,    0,    0,  963,
      973,    0,    0,    0,  989,  975,    0,  978,  994, 1000,
        0,  990,  995,  982,  998,    0,    0,    0,  995,    0,
      995, 1006, 1001,    0,  997, 1058, 1003, 1067,    0, 1075,

     1067, 1071,    0,    0, 1061,    0,    0,    0, 1066, 1071,
        0, 1062, 1073,    0, 1089, 1064, 1069, 1074,    0, 1079,
        0,    0, 1070, 1082, 1066, 1141, 1069, 1086, 1069, 1086,
     1078, 1088,    0, 1091,    0, 1076, 1085, 1078,    0, 1695,
     1104, 1134, 1121, 1135,  468, 1152, 1156, 1138, 1138, 1151,
      416, 1139,  398, 1695,    0, 1166, 1144,    0, 1149, 1161,
     1154, 1157,    0,    0,    0, 1148, 1160,    0,    0, 1162,
        0, 1165,    0,  382, 1170, 1171,    0, 1174, 1169, 1170,
     1163,    0, 1176,    0, 1179, 1171, 1175,    0,    0, 1185,
        0,    0, 1238,    0,    0, 1188, 1205, 1252, 1260, 1231,

     1216,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      407, 1224, 1255, 1256, 1255, 1254, 1245,    0, 1256,    0,
     1259, 1265, 1249,    0,    0,    0, 1264, 1265, 1266,  360,
     1258,  361, 1695,  333, 1265, 1266, 1267, 1695,  330, 1268,
     1269, 1270, 1695,  306, 1278, 1259, 1281, 1276, 1279, 1280,
      297, 1292,    0, 1291,    0, 1280,    0, 1309,    0, 1299,
     1309, 1303,    0,  241,  240, 1317,    0, 1297, 1308, 1320,
        0, 1338, 1330,    0,    0, 1327, 1325,    0, 1332, 1320,
     1328,    0, 1337, 1323, 1343, 1343, 1348, 1338,    0,    0,
     1695, 1371, 1350,  250, 1348, 1695, 1695, 1695, 1349, 1695,

     1695, 1695,  308, 1695,  326, 1340, 1347, 1345, 1356, 1350,
     1357, 1353,  207, 1355,    0, 1361, 1357, 1363, 1383, 1373,
      204,  191, 1369, 1382, 1391,    0, 1388, 1387, 1381,    0,
     1382,    0, 1402,    0,    0, 1400,    0,  142, 1395, 1397,
     1408, 1402, 1695, 1695, 1410, 1396, 1413, 1400,  374, 1398,
     1402,    0, 1425, 1422, 1427, 1415, 1419, 1416,    0,    0,
        0, 1421, 1439, 1431,    0,    0,    0,    0, 1436, 1433,
     1434, 1450, 1437, 1695, 1695,  128, 1451, 1443,  412, 1695,
      476, 1444, 1454,    0, 1453,    0, 1448, 1456, 1462, 1468,
     1451, 1473, 1461, 1460, 1472, 1473, 1474, 1493,  530, 1484,

     1470,    0, 1471,    0,    0, 1466,    0, 1488, 1492,    0,
     1507,    0, 1695, 1504, 1486, 1507,  556, 1695,  594, 1501,
      126,    0, 1509,    0, 1503, 1493, 1512, 1520, 1519,  707,
     1512,    0, 1524, 1516, 1695, 1528, 1524,  709, 1695,  722,
     1533, 1520,    0, 1531, 1525, 1528, 1523, 1529, 1532, 1531,
     1532, 1544, 1565,    0, 1558, 1563, 1554, 1558, 1556, 1554,
     1572, 1695, 1560,  119, 1578,  100, 1563, 1695, 1565, 1561,
     1578, 1572, 1563, 1585, 1586, 1695, 1695, 1695, 1648, 1652,
     1656, 1660, 1664, 1666, 1670, 1674,  117,  111, 1678, 1682,
     1686, 1690

    } ;

static const flex_int16_t yy_def[693] =
    {   0,
      678,    1,  679,  679,  680,  680,  681,  681,  681,  681,
      682,  682,  683,  683,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  685,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,

      678,  678,  678,  678,  678,  686,  678,  678,  687,  678,
      678,  678,  678,  678,  678,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,

      684,  678,  678,  678,  685,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  686,  678,  686,  678,  688,  678,
      678,  678,  678,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  678,

      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  688,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  678,  684,

      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  689,  678,  678,  678,  678,  678,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,

      678,  678,  689,  678,  689,  678,  678,  678,  678,  678,
      678,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  690,  678,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  678,  678,  678,  678,  678,  678,  678,  690,  678,
      690,  678,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  678,  678,  678,  691,  678,

      678,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  678,  678,  678,  678,  691,  678,  691,  678,
      678,  684,  684,  684,  684,  684,  678,  678,  678,  692,
      678,  684,  684,  684,  678,  678,  678,  692,  678,  692,
      678,  678,  684,  684,  678,  678,  678,  678,  684,  678,
      678,  678,  678,  684,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,    0,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678

    } ;

static const flex_int16_t yy_nxt[1781] =
    {   0,
       16,   17,   18,   16,   17,   16,   19,   20,   21,   22,
       23,   24,   25,   26,   27,   28,   29,   29,   29,   29,
       29,   29,   29,   30,   31,   32,   33,   34,   35,   36,
       37,   38,   39,   40,   41,   42,   43,   44,   45,   46,
       47,   48,   49,   50,   45,   51,   52,   53,   54,   55,
       56,   57,   45,   45,   58,   59,   45,   35,   36,   37,
       38,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       48,   49,   50,   45,   51,   52,   53,   54,   55,   56,
       57,   45,   45,   60,   61,   63,   64,   63,   64,   67,
       88,   90,   65,   67,   65,   72,   72,   72,   72,   72,

       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   87,  105,  355,   87,   87,   89,  106,   87,  229,
       90,   91,   91,   91,   91,   91,   91,   91,   91,  149,
      126,  154,  171,  201,  211,  127,  212,   68,   69,   70,
       71,   68,   69,   70,   71,   89,  107,  128,  108,  108,
      108,  108,  108,  108,  108,  108,  669,  215,  149,  126,
      154,  171,  201,  211,  127,  212,   68,   69,   70,   71,
       68,   69,   70,   71,   67,  667,  128,  226,  227,  226,
      227,  216,  631,   75,  598,   76,  215,   77,   77,   77,
       77,   77,   77,   77,   77,  217,   78,   79,  570,   80,

       67,  206,  206,  206,  206,  206,  206,  206,  206,   75,
      216,   76,  560,   77,   77,   77,   77,   77,   77,   77,
       77,  559,   78,   79,  217,   80,   67,  107,  552,  108,
      108,  108,  108,  108,  108,  108,  108,  226,  227,   82,
       82,   82,   82,   82,   82,   82,   82,  364,  365,  110,
      213,  111,  214,  112,  494,  138,  522,  139,  140,  521,
      218,  219,  220,  223,  224,  109,  196,  141,  113,  114,
      115,  129,  130,  197,   83,   84,   85,   86,  110,  213,
      111,  214,  112,  131,  138,  132,  139,  140,  133,  218,
      219,  220,  223,  224,  109,  196,  141,  113,  114,  115,

      129,  130,  197,   83,   84,   85,   86,   67,  504,  505,
      504,  505,  131,  513,  132,  233,  134,  133,  234,  235,
       82,   82,   82,   82,   82,   82,   82,   82,  504,  505,
      135,  136,  221,  238,  137,  239,  142,  143,  142,  144,
      142,  142,  142,  142,  233,  134,  236,  234,  235,  237,
      145,  499,  240,  222,  495,   83,   84,   85,   86,  135,
      136,  221,  238,  137,  239,  494,  146,  147,  147,  147,
      147,  147,  147,  147,  147,  236,  580,  581,  237,  145,
      148,  240,  222,  188,   83,   84,   85,   86,   92,  241,
       93,   94,   95,  189,   96,  146,  242,  243,   97,   98,

      190,   99,  100,  250,  251,  101,  102,  259,  103,  148,
      264,  267,  188,  104,  580,  581,  492,   92,  241,   93,
       94,   95,  189,   96,  478,  242,  243,   97,   98,  190,
       99,  100,  250,  251,  101,  102,  259,  103,  460,  264,
      267,  252,  104,  116,  116,  116,  116,  116,  116,  116,
      116,  244,  268,  150,  449,  245,  253,  269,  118,  119,
      151,  152,  172,  153,  246,  173,  198,  120,  121,  122,
      252,  174,  447,  199,  123,  124,  433,  125,  580,  581,
      244,  268,  150,  200,  245,  253,  269,  118,  119,  151,
      152,  172,  153,  246,  173,  198,  120,  121,  122,  340,

      174,  155,  199,  123,  124,  156,  125,  157,  203,  208,
      158,  209,  200,  247,  248,  249,  203,  210,  159,  204,
      204,  204,  204,  204,  204,  204,  204,  260,  261,  262,
      155,  274,  618,  619,  156,  271,  157,  270,  208,  158,
      209,  202,  247,  248,  249,  263,  210,  159,  160,  160,
      160,  160,  160,  160,  160,  160,  265,  275,  618,  619,
      274,  161,  167,  168,  168,  168,  168,  168,  168,  168,
      266,  191,  162,  192,  263,  163,  254,  255,  164,  165,
      272,  166,  256,  678,  273,  265,  275,  193,  194,  169,
      161,  230,  195,  231,  276,  170,  618,  619,   73,  266,

      191,  162,  192,   73,  163,  254,  255,  164,  165,  272,
      166,  256,  232,  273,  277,  678,  193,  194,  169,  678,
      230,  195,  231,  276,  170,  147,  147,  147,  147,  147,
      147,  147,  147,  207,  207,  207,  207,  207,  207,  207,
      207,  232,  175,  277,  280,  282,  281,  283,  278,  176,
      284,  177,  286,  287,  288,  107,  178,   91,   91,   91,
       91,   91,   91,   91,   91,  678,  279,  293,  285,  294,
      295,  175,  299,  280,  282,  281,  283,  278,  176,  284,
      177,  286,  287,  288,  305,  178,  179,  306,  180,  309,
      181,  312,  313,  182,  183,  279,  293,  285,  294,  295,

      307,  299,  184,  185,  314,  317,  186,  308,  187,  639,
      640,  639,  640,  305,  678,  179,  306,  180,  309,  181,
      312,  313,  182,  183,  639,  640,  678,  678,  678,  307,
      678,  184,  185,  314,  317,  186,  308,  187,  228,  228,
      228,  228,  228,  228,  228,  228,  107,  678,  108,  108,
      108,  108,  108,  108,  108,  108,  116,  116,  116,  116,
      116,  116,  116,  116,  257,  257,  257,  257,  257,  257,
      257,  257,  147,  147,  147,  147,  147,  147,  147,  147,
      678,  258,  160,  160,  160,  160,  160,  160,  160,  160,
      289,  290,  296,  296,  296,  296,  296,  296,  296,  296,

      678,  678,  678,  678,  678,  297,  291,  292,  298,  300,
      258,  168,  168,  168,  168,  168,  168,  168,  168,  289,
      290,  168,  168,  168,  168,  168,  168,  168,  168,  301,
      310,  315,  323,  318,  297,  291,  292,  298,  302,  324,
      316,  303,  319,  325,  320,  304,  321,  328,  329,  311,
      330,  331,  322,  678,  678,  678,  678,  678,  301,  310,
      315,  323,  318,  332,  333,  334,  335,  302,  324,  316,
      303,  319,  325,  320,  304,  321,  328,  329,  311,  330,
      331,  322,  326,  326,  326,  326,  326,  326,  326,  326,
      336,  337,  332,  333,  334,  335,  338,  327,  339,  203,

      206,  206,  206,  206,  206,  206,  206,  206,  341,  342,
      204,  204,  204,  204,  204,  204,  204,  204,  343,  336,
      337,  344,  345,  346,  347,  338,  327,  339,  207,  207,
      207,  207,  207,  207,  207,  207,  348,  341,  342,  349,
      351,  352,  350,  353,  354,  678,  678,  343,  678,  678,
      344,  345,  346,  347,  228,  228,  228,  228,  228,  228,
      228,  228,  358,  359,  360,  348,  361,  362,  349,  351,
      352,  350,  353,  354,  356,  356,  356,  356,  356,  356,
      356,  356,  363,  366,  367,  368,  369,  370,  371,  372,
      373,  358,  359,  360,  374,  361,  362,  257,  257,  257,

      257,  257,  257,  257,  257,  375,  376,  377,  378,  357,
      379,  363,  366,  367,  368,  369,  370,  371,  372,  373,
      380,  381,  382,  374,  383,  384,  388,  389,  390,  391,
      392,  385,  386,  393,  375,  376,  377,  378,  357,  379,
      387,  394,  395,  396,  678,  678,  678,  678,  678,  380,
      381,  382,  397,  383,  384,  388,  389,  390,  391,  392,
      385,  386,  393,  678,  678,  678,  678,  678,  678,  387,
      394,  395,  396,  296,  296,  296,  296,  296,  296,  296,
      296,  397,  398,  398,  398,  398,  398,  398,  398,  398,
      399,  399,  399,  399,  399,  399,  399,  399,  400,  401,

      402,  403,  404,  405,  406,  407,  410,  412,  413,  414,
      415,  416,  417,  418,  419,  420,  421,  411,  422,  423,
      424,  408,  425,  426,  427,  428,  409,  400,  401,  402,
      403,  404,  405,  406,  407,  429,  412,  413,  414,  415,
      416,  417,  418,  419,  420,  421,  411,  422,  423,  424,
      408,  425,  426,  427,  428,  409,  326,  326,  326,  326,
      326,  326,  326,  326,  429,  430,  431,  432,  434,  435,
      444,  436,  439,  440,  437,  441,  678,  445,  442,  446,
      448,  356,  356,  356,  356,  356,  356,  356,  356,  450,
      451,  452,  453,  454,  430,  431,  432,  455,  456,  444,

      457,  438,  461,  462,  458,  443,  445,  463,  446,  448,
      459,  464,  465,  466,  467,  468,  469,  470,  450,  451,
      452,  453,  454,  471,  678,  678,  455,  456,  678,  457,
      438,  461,  462,  458,  443,  474,  463,  475,  678,  459,
      464,  465,  466,  467,  468,  469,  470,  678,  678,  678,
      678,  678,  471,  472,  472,  472,  472,  472,  472,  472,
      472,  476,  477,  479,  474,  678,  475,  398,  398,  398,
      398,  398,  398,  398,  398,  399,  399,  399,  399,  399,
      399,  399,  399,  480,  481,  482,  483,  484,  485,  486,
      476,  477,  479,  487,  473,  488,  489,  490,  491,  493,

      496,  497,  498,  500,  501,  502,  506,  507,  510,  511,
      512,  508,  480,  481,  482,  483,  484,  485,  486,  509,
      514,  515,  487,  516,  488,  489,  490,  491,  493,  496,
      497,  498,  500,  501,  502,  506,  507,  510,  511,  512,
      508,  517,  518,  519,  520,  523,  524,  525,  509,  514,
      515,  526,  516,  472,  472,  472,  472,  472,  472,  472,
      472,  527,  528,  530,  531,  532,  529,  533,  534,  535,
      517,  518,  519,  520,  523,  524,  525,  536,  537,  538,
      526,  539,  542,  543,  544,  545,  546,  547,  548,  549,
      527,  528,  530,  531,  532,  529,  533,  534,  535,  550,

      551,  540,  553,  554,  555,  556,  536,  537,  538,  541,
      539,  542,  543,  544,  545,  546,  547,  548,  549,  557,
      558,  561,  562,  563,  564,  565,  566,  567,  550,  551,
      540,  553,  554,  555,  556,  568,  569,  571,  541,  572,
      573,  574,  575,  576,  577,  578,  582,  583,  557,  558,
      561,  562,  563,  564,  565,  566,  567,  584,  585,  586,
      587,  588,  589,  590,  568,  569,  571,  591,  572,  573,
      574,  575,  576,  577,  578,  582,  583,  592,  593,  594,
      595,  596,  597,  599,  600,  601,  584,  585,  586,  587,
      588,  589,  590,  602,  603,  604,  591,  605,  606,  607,

      608,  609,  610,  611,  612,  613,  592,  593,  594,  595,
      596,  597,  599,  600,  601,  614,  620,  621,  622,  623,
      624,  625,  602,  603,  604,  615,  605,  606,  607,  608,
      609,  610,  611,  612,  613,  626,  627,  628,  616,  629,
      630,  632,  633,  634,  614,  620,  621,  622,  623,  624,
      625,  635,  636,  637,  615,  641,  643,  644,  645,  642,
      646,  647,  648,  649,  626,  627,  628,  616,  629,  630,
      632,  633,  634,  650,  651,  652,  653,  654,  655,  656,
      635,  636,  637,  657,  641,  643,  644,  645,  642,  646,
      647,  648,  649,  658,  659,  660,  661,  662,  663,  664,

      665,  666,  650,  651,  652,  653,  654,  655,  656,  668,
      670,  671,  657,  672,  673,  674,  675,  676,  677,  678,
      678,  678,  658,  659,  660,  661,  662,  663,  664,  665,
      666,  678,  678,  678,  678,  678,  678,  678,  668,  670,
      671,  678,  672,  673,  674,  675,  676,  677,   62,   62,
       62,   62,   66,   66,   66,   66,   67,   67,   67,   67,
       74,   74,   74,   74,   81,   81,   81,   81,  117,  117,
      205,  678,  205,  205,  225,  225,  225,  225,  503,  503,
      503,  503,  579,  579,  579,  579,  617,  617,  617,  617,
      638,  638,  638,  638,   15,  678,  678,  678,  678,  678,

      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678
    } ;

static const flex_int16_t yy_chk[1781] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    4,    4,    5,
       19,   20,    3,    6,    4,    7,    7,    7,    7,    7,

        7,    7,    7,    8,    8,    8,    8,    8,    8,    8,
        8,   17,   27,  688,   17,   87,   19,   27,   87,  687,
       20,   25,   25,   25,   25,   25,   25,   25,   25,   42,
       36,   44,   49,   57,   89,   36,   90,    5,    5,    5,
        5,    6,    6,    6,    6,   19,   29,   36,   29,   29,
       29,   29,   29,   29,   29,   29,  666,   93,   42,   36,
       44,   49,   57,   89,   36,   90,    5,    5,    5,    5,
        6,    6,    6,    6,   11,  664,   36,  106,  106,  225,
      225,   94,  621,   11,  576,   11,   93,   11,   11,   11,
       11,   11,   11,   11,   11,   95,   11,   11,  538,   11,

       12,   77,   77,   77,   77,   77,   77,   77,   77,   12,
       94,   12,  522,   12,   12,   12,   12,   12,   12,   12,
       12,  521,   12,   12,   95,   12,   13,   28,  513,   28,
       28,   28,   28,   28,   28,   28,   28,  227,  227,   13,
       13,   13,   13,   13,   13,   13,   13,  245,  245,   30,
       92,   30,   92,   30,  494,   39,  465,   39,   39,  464,
       96,   97,   98,  101,  102,   28,   55,   39,   30,   30,
       30,   37,   37,   55,   13,   13,   13,   13,   30,   92,
       30,   92,   30,   37,   39,   37,   39,   39,   37,   96,
       97,   98,  101,  102,   28,   55,   39,   30,   30,   30,

       37,   37,   55,   13,   13,   13,   13,   14,  444,  444,
      503,  503,   37,  451,   37,  114,   38,   37,  118,  119,
       14,   14,   14,   14,   14,   14,   14,   14,  505,  505,
       38,   38,   99,  121,   38,  122,   40,   40,   40,   40,
       40,   40,   40,   40,  114,   38,  120,  118,  119,  120,
       40,  439,  123,   99,  434,   14,   14,   14,   14,   38,
       38,   99,  121,   38,  122,  432,   40,   41,   41,   41,
       41,   41,   41,   41,   41,  120,  549,  549,  120,   40,
       41,  123,   99,   53,   14,   14,   14,   14,   26,  124,
       26,   26,   26,   53,   26,   40,  125,  126,   26,   26,

       53,   26,   26,  129,  130,   26,   26,  134,   26,   41,
      137,  139,   53,   26,  579,  579,  430,   26,  124,   26,
       26,   26,   53,   26,  411,  125,  126,   26,   26,   53,
       26,   26,  129,  130,   26,   26,  134,   26,  374,  137,
      139,  131,   26,   35,   35,   35,   35,   35,   35,   35,
       35,  127,  140,   43,  353,  127,  131,  141,   35,   35,
       43,   43,   50,   43,  127,   50,   56,   35,   35,   35,
      131,   50,  351,   56,   35,   35,  345,   35,  581,  581,
      127,  140,   43,   56,  127,  131,  141,   35,   35,   43,
       43,   50,   43,  127,   50,   56,   35,   35,   35,  205,

       50,   46,   56,   35,   35,   46,   35,   46,   72,   88,
       46,   88,   56,  128,  128,  128,  203,   88,   46,   72,
       72,   72,   72,   72,   72,   72,   72,  136,  136,  136,
       46,  146,  599,  599,   46,  144,   46,  143,   88,   46,
       88,   65,  128,  128,  128,  136,   88,   46,   47,   47,
       47,   47,   47,   47,   47,   47,  138,  148,  617,  617,
      146,   47,   48,   48,   48,   48,   48,   48,   48,   48,
      138,   54,   47,   54,  136,   47,  132,  132,   47,   47,
      145,   47,  132,   15,  145,  138,  148,   54,   54,   48,
       47,  113,   54,  113,  149,   48,  619,  619,   10,  138,

       54,   47,   54,    9,   47,  132,  132,   47,   47,  145,
       47,  132,  113,  145,  150,    0,   54,   54,   48,    0,
      113,   54,  113,  149,   48,   51,   51,   51,   51,   51,
       51,   51,   51,   82,   82,   82,   82,   82,   82,   82,
       82,  113,   51,  150,  152,  154,  152,  155,  151,   51,
      156,   51,  157,  158,  159,   91,   51,   91,   91,   91,
       91,   91,   91,   91,   91,    0,  151,  162,  156,  163,
      164,   51,  166,  152,  154,  152,  155,  151,   51,  156,
       51,  157,  158,  159,  170,   51,   52,  172,   52,  174,
       52,  176,  177,   52,   52,  151,  162,  156,  163,  164,

      173,  166,   52,   52,  178,  180,   52,  173,   52,  630,
      630,  638,  638,  170,    0,   52,  172,   52,  174,   52,
      176,  177,   52,   52,  640,  640,    0,    0,    0,  173,
        0,   52,   52,  178,  180,   52,  173,   52,  107,  107,
      107,  107,  107,  107,  107,  107,  108,    0,  108,  108,
      108,  108,  108,  108,  108,  108,  116,  116,  116,  116,
      116,  116,  116,  116,  133,  133,  133,  133,  133,  133,
      133,  133,  147,  147,  147,  147,  147,  147,  147,  147,
        0,  133,  160,  160,  160,  160,  160,  160,  160,  160,
      161,  161,  165,  165,  165,  165,  165,  165,  165,  165,

        0,    0,    0,    0,    0,  165,  161,  161,  165,  167,
      133,  167,  167,  167,  167,  167,  167,  167,  167,  161,
      161,  168,  168,  168,  168,  168,  168,  168,  168,  169,
      175,  179,  183,  181,  165,  161,  161,  165,  169,  183,
      179,  169,  181,  184,  181,  169,  182,  186,  187,  175,
      188,  189,  182,    0,    0,    0,    0,    0,  169,  175,
      179,  183,  181,  190,  193,  194,  197,  169,  183,  179,
      169,  181,  184,  181,  169,  182,  186,  187,  175,  188,
      189,  182,  185,  185,  185,  185,  185,  185,  185,  185,
      198,  199,  190,  193,  194,  197,  200,  185,  201,  204,

      206,  206,  206,  206,  206,  206,  206,  206,  208,  209,
      204,  204,  204,  204,  204,  204,  204,  204,  210,  198,
      199,  211,  212,  213,  214,  200,  185,  201,  207,  207,
      207,  207,  207,  207,  207,  207,  215,  208,  209,  216,
      217,  219,  216,  223,  224,    0,    0,  210,    0,    0,
      211,  212,  213,  214,  228,  228,  228,  228,  228,  228,
      228,  228,  235,  236,  237,  215,  238,  241,  216,  217,
      219,  216,  223,  224,  234,  234,  234,  234,  234,  234,
      234,  234,  243,  246,  249,  250,  251,  252,  253,  254,
      255,  235,  236,  237,  259,  238,  241,  257,  257,  257,

      257,  257,  257,  257,  257,  264,  265,  266,  267,  234,
      270,  243,  246,  249,  250,  251,  252,  253,  254,  255,
      271,  275,  276,  259,  278,  279,  282,  283,  284,  285,
      289,  280,  280,  291,  264,  265,  266,  267,  234,  270,
      280,  292,  293,  295,    0,    0,    0,    0,    0,  271,
      275,  276,  297,  278,  279,  282,  283,  284,  285,  289,
      280,  280,  291,    0,    0,    0,    0,    0,    0,  280,
      292,  293,  295,  296,  296,  296,  296,  296,  296,  296,
      296,  297,  298,  298,  298,  298,  298,  298,  298,  298,
      300,  300,  300,  300,  300,  300,  300,  300,  301,  302,

      305,  309,  310,  312,  313,  313,  315,  316,  317,  318,
      320,  323,  324,  325,  327,  328,  329,  315,  330,  331,
      332,  313,  334,  336,  337,  338,  313,  301,  302,  305,
      309,  310,  312,  313,  313,  341,  316,  317,  318,  320,
      323,  324,  325,  327,  328,  329,  315,  330,  331,  332,
      313,  334,  336,  337,  338,  313,  326,  326,  326,  326,
      326,  326,  326,  326,  341,  342,  343,  344,  346,  346,
      348,  346,  347,  347,  346,  347,    0,  349,  347,  350,
      352,  356,  356,  356,  356,  356,  356,  356,  356,  357,
      359,  360,  361,  362,  342,  343,  344,  366,  367,  348,

      370,  346,  375,  376,  372,  347,  349,  378,  350,  352,
      372,  379,  380,  381,  383,  385,  386,  387,  357,  359,
      360,  361,  362,  390,    0,    0,  366,  367,    0,  370,
      346,  375,  376,  372,  347,  396,  378,  397,    0,  372,
      379,  380,  381,  383,  385,  386,  387,    0,    0,    0,
        0,    0,  390,  393,  393,  393,  393,  393,  393,  393,
      393,  400,  401,  412,  396,    0,  397,  398,  398,  398,
      398,  398,  398,  398,  398,  399,  399,  399,  399,  399,
      399,  399,  399,  413,  414,  415,  416,  417,  419,  421,
      400,  401,  412,  422,  393,  423,  427,  428,  429,  431,

      435,  436,  437,  440,  441,  442,  445,  446,  448,  449,
      450,  447,  413,  414,  415,  416,  417,  419,  421,  447,
      452,  454,  422,  456,  423,  427,  428,  429,  431,  435,
      436,  437,  440,  441,  442,  445,  446,  448,  449,  450,
      447,  458,  460,  461,  462,  466,  468,  469,  447,  452,
      454,  470,  456,  472,  472,  472,  472,  472,  472,  472,
      472,  473,  476,  477,  479,  480,  476,  481,  483,  484,
      458,  460,  461,  462,  466,  468,  469,  485,  486,  487,
      470,  488,  493,  495,  499,  506,  507,  508,  509,  510,
      473,  476,  477,  479,  480,  476,  481,  483,  484,  511,

      512,  492,  514,  516,  517,  518,  485,  486,  487,  492,
      488,  493,  495,  499,  506,  507,  508,  509,  510,  519,
      520,  523,  524,  525,  527,  528,  529,  531,  511,  512,
      492,  514,  516,  517,  518,  533,  536,  539,  492,  540,
      541,  542,  545,  546,  547,  548,  550,  551,  519,  520,
      523,  524,  525,  527,  528,  529,  531,  553,  554,  555,
      556,  557,  558,  562,  533,  536,  539,  563,  540,  541,
      542,  545,  546,  547,  548,  550,  551,  564,  569,  570,
      571,  572,  573,  577,  578,  582,  553,  554,  555,  556,
      557,  558,  562,  583,  585,  587,  563,  588,  589,  590,

      591,  592,  593,  594,  595,  596,  564,  569,  570,  571,
      572,  573,  577,  578,  582,  597,  600,  601,  603,  606,
      608,  609,  583,  585,  587,  598,  588,  589,  590,  591,
      592,  593,  594,  595,  596,  611,  614,  615,  598,  616,
      620,  623,  625,  626,  597,  600,  601,  603,  606,  608,
      609,  627,  628,  629,  598,  631,  633,  634,  636,  631,
      637,  641,  642,  644,  611,  614,  615,  598,  616,  620,
      623,  625,  626,  645,  646,  647,  648,  649,  650,  651,
      627,  628,  629,  652,  631,  633,  634,  636,  631,  637,
      641,  642,  644,  653,  655,  656,  657,  658,  659,  660,

      661,  663,  645,  646,  647,  648,  649,  650,  651,  665,
      667,  669,  652,  670,  671,  672,  673,  674,  675,    0,
        0,    0,  653,  655,  656,  657,  658,  659,  660,  661,
      663,    0,    0,    0,    0,    0,    0,    0,  665,  667,
      669,    0,  670,  671,  672,  673,  674,  675,  679,  679,
      679,  679,  680,  680,  680,  680,  681,  681,  681,  681,
      682,  682,  682,  682,  683,  683,  683,  683,  684,  684,
      685,    0,  685,  685,  686,  686,  686,  686,  689,  689,
      689,  689,  690,  690,  690,  690,  691,  691,  691,  691,
      692,  692,  692,  692,  678,  678,  678,  678,  678,  678,

      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  678,  678
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[244] =
    {   0,
1, 1, 1, 1, 1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../igt-gpu-tools-2.5/assembler/lex.l"
#line 3 "../igt-gpu-tools-2.5/assembler/lex.l"
#include <string.h>
#include "gen4asm.h"
#include "gram.h"
#include "brw_defines.h"

#include "string.h"
int saved_state = 0;
extern const char *input_filename;

/* Locations */
int yycolumn = 1;

#define YY_NO_INPUT
#define YY_USER_ACTION						\
	yylloc.first_line = yylloc.last_line = yylineno;	\
	yylloc.first_column = yycolumn;				\
	yylloc.last_column = yycolumn+yyleng-1;			\
	yycolumn += yyleng;

#line 1118 "assembler/intel-gen4asm.p/lex.c"

#line 1120 "assembler/intel-gen4asm.p/lex.c"

#define INITIAL 0
#define BLOCK_COMMENT 1
#define CHANNEL 2
#define LINENUMBER 3
#define FILENAME 4
#define REG 5
#define DOTSEL 6

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 30 "../igt-gpu-tools-2.5/assembler/lex.l"

#line 1345 "assembler/intel-gen4asm.p/lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 679 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1695 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 31 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yycolumn = 1; } /* eat up single-line comments */
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 32 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yycolumn = 1; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 33 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yycolumn = 1; }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 34 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yycolumn = 1; }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 35 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yycolumn = 1; }
	YY_BREAK
/* eat up multi-line comments, non-nesting. */
case 6:
YY_RULE_SETUP
#line 38 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	saved_state = YYSTATE;
	BEGIN(BLOCK_COMMENT);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 42 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	BEGIN(saved_state);
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 45 "../igt-gpu-tools-2.5/assembler/lex.l"
{ }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 46 "../igt-gpu-tools-2.5/assembler/lex.l"
{ }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 47 "../igt-gpu-tools-2.5/assembler/lex.l"
{ 
	yycolumn = 1;
	saved_state = YYSTATE;
	BEGIN(LINENUMBER);
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 52 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylineno = atoi (yytext) - 1;
	BEGIN(FILENAME);
}
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 56 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	char *name = malloc (yyleng - 1);
	memmove (name, yytext + 1, yyleng - 2);
	name[yyleng-1] = '\0';
	input_filename = name;
	BEGIN(saved_state);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 64 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CHANNEL_X;
	return X;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 68 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CHANNEL_Y;
	return Y;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 72 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CHANNEL_Z;
	return Z;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 76 "../igt-gpu-tools-2.5/assembler/lex.l"
{
yylval.integer = BRW_CHANNEL_W;
	return W;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 80 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yyless(0);
	BEGIN(INITIAL);
}
	YY_BREAK
/* used for both null send and null register. */
case 18:
YY_RULE_SETUP
#line 86 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return NULL_TOKEN; }
	YY_BREAK
/* opcodes */
case 19:
YY_RULE_SETUP
#line 89 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_MOV; return MOV; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 90 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_FRC; return FRC; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 91 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_RNDU; return RNDU; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 92 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_RNDD; return RNDD; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 93 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_RNDE; return RNDE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 94 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_RNDZ; return RNDZ; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 95 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_NOT; return NOT; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 96 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_LZD; return LZD; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 97 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_F16TO32; return F16TO32; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 98 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_F32TO16; return F32TO16; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 99 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_FBH; return FBH; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 100 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_FBL; return FBL; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 102 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_MAD; return MAD; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 103 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_LRP; return LRP; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 104 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_BFE; return BFE; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 105 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_BFI1; return BFI1; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 106 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_BFI2; return BFI2; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 107 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_BFREV; return BFREV; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 108 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_MUL; return MUL; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 109 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_MAC; return MAC; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 110 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_MACH; return MACH; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 111 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_LINE; return LINE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 112 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SAD2; return SAD2; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 113 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SADA2; return SADA2; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 114 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_DP4; return DP4; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 115 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_DPH; return DPH; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 116 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_DP3; return DP3; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 117 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_DP2; return DP2; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 119 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_CBIT; return CBIT; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 120 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_AVG; return AVG; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 121 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_ADD; return ADD; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 122 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_ADDC; return ADDC; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 123 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SEL; return SEL; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 124 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_AND; return AND; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 125 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_OR; return OR; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 126 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_XOR; return XOR; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 127 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SHR; return SHR; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 128 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SHL; return SHL; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 129 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_ASR; return ASR; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 130 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_CMP; return CMP; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 131 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_CMPN; return CMPN; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 132 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SUBB; return SUBB; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 134 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SEND; return SEND; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 135 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_SENDC; return SENDC; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 136 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_NOP; return NOP; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 137 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_JMPI; return JMPI; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 138 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_IF; return IF; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 139 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_IFF; return IFF; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 140 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_WHILE; return WHILE; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 141 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_ELSE; return ELSE; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 142 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_BREAK; return BREAK; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 143 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_CONTINUE; return CONT; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 144 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_HALT; return HALT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 145 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_MSAVE; return MSAVE; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 146 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_PUSH; return PUSH; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 147 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_MRESTORE; return MREST; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 148 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_POP; return POP; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 149 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_WAIT; return WAIT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 150 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_DO; return DO; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 151 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_ENDIF; return ENDIF; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 152 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_CALL; return CALL; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 153 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_RET; return RET; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 154 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_BRD; return BRD; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 155 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_BRC; return BRC; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 157 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_OPCODE_PLN; return PLN; }
	YY_BREAK
/* send argument tokens */
case 84:
YY_RULE_SETUP
#line 160 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return MSGLEN; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 161 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return RETURNLEN; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 162 "../igt-gpu-tools-2.5/assembler/lex.l"
{ if (IS_GENp(6)) { yylval.integer = BRW_OPCODE_MATH; return MATH_INST; } else return MATH; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 163 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SAMPLER; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 164 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return GATEWAY; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 165 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return READ; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 166 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return WRITE; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 167 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return URB; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 168 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return THREAD_SPAWNER; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 169 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return VME; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 170 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return CRE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 171 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return DATA_PORT; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 173 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALLOCATE; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 174 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return USED; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 175 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return COMPLETE; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 176 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TRANSPOSE; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 177 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return INTERLEAVE; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 179 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SEMICOLON; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 180 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return LPAREN; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 181 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return RPAREN; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 182 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return LANGLE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 183 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return RANGLE; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 184 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return LCURLY; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 185 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return RCURLY; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 186 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return LSQUARE; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 187 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return RSQUARE; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 188 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return COMMA; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 189 "../igt-gpu-tools-2.5/assembler/lex.l"
{ BEGIN(CHANNEL); return DOT; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 190 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return PLUS; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 191 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return MINUS; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 192 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return MULTIPLY;}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 193 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return DIVIDE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 194 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return COLON; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 195 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return EQ; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 196 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ABS; }
	YY_BREAK
/* Most register accesses are lexed as REGFILE[0-9]+, to prevent the register
  * with subreg from being lexed as REGFILE NUMBER instead of
  * REGISTER INTEGER DOT INTEGER like we want.  The alternative was to use a
  * start condition, which wasn't very clean-looking.
  *
  * However, this means we need to lex the general and message register file
  * characters as well, for register-indirect access which is formatted
  * like g[a#.#] or m[a#.#].
  */
case 119:
YY_RULE_SETUP
#line 207 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 3);
	return ACCREG;
}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 211 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 1);
	return ADDRESSREG;
}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 215 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 1);
	return MSGREG;
}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 219 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	return MSGREGFILE;
}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 222 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 4);
	return MASKREG;
}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 226 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 2);
	return MASKSTACKREG;
}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 230 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 3);
	return MASKSTACKDEPTHREG;
}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 235 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 3);
	return NOTIFYREG;
}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 240 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 1);
	return NOTIFYREG;
}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 245 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 1);
	return FLAGREG;
}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 250 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 1);
	BEGIN(REG);
	return GENREG;
}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 255 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return LANGLE; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 256 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = strtoul(yytext, NULL, 10);
	return INTEGER;
}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 260 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return RANGLE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 262 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return COMMA; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 263 "../igt-gpu-tools-2.5/assembler/lex.l"
{ BEGIN(DOTSEL); return DOT; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 264 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SEMICOLON; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 266 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CHANNEL_X;
	return X;
}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 270 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CHANNEL_Y;
	return Y;
}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 274 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CHANNEL_Z;
	return Z;
}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 278 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CHANNEL_W;
	return W;
}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 282 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = strtoul(yytext, NULL, 10);
	BEGIN(REG);
	return INTEGER;
}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 287 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yyless(0);
	BEGIN(INITIAL);
}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 292 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	return GENREGFILE;
}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 295 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 2);
	return CONTROLREG;
}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 299 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = atoi(yytext + 2);
	return STATEREG;
}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 303 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	return IPREG;
}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 306 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_AMASK;
	return AMASK;
}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 310 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_IMASK;
	return IMASK;
}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 314 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_LMASK;
	return LMASK;
}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 318 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_CMASK;
	return CMASK;
}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 322 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = 0;
	return IMSD;
}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 326 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = 1;
	return LMSD;
}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 330 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = 0;
	return IMS;
}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 334 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = 16;
	return LMS;
}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 339 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yyless(0);
	BEGIN(INITIAL);
}
	YY_BREAK
/*
  * Lexing of register types should probably require the ":" symbol specified
  * in the BNF of the assembly, but our existing source didn't use that syntax.
  */
case 155:
YY_RULE_SETUP
#line 348 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_UD; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 349 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_UD; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 350 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_D; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 351 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_D; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 352 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_UW; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 353 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_UW; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 354 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_W; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 355 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_W; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 356 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_UB; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 357 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_UB; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 358 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_B; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 359 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_B; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 360 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_F; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 361 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_F; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 362 "../igt-gpu-tools-2.5/assembler/lex.l"
{return TYPE_VF; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 363 "../igt-gpu-tools-2.5/assembler/lex.l"
{return TYPE_VF; }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 364 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_V; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 365 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE_V; }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 367 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return KERNEL_PRAGMA;}
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 368 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return END_KERNEL_PRAGMA;}
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 369 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return CODE_PRAGMA;}
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 370 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return END_CODE_PRAGMA;}
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 371 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return REG_COUNT_PAYLOAD_PRAGMA; }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 372 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return REG_COUNT_TOTAL_PRAGMA; }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 373 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return DEFAULT_EXEC_SIZE_PRAGMA; }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 374 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return DEFAULT_REG_TYPE_PRAGMA; }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 375 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return DECLARE_PRAGMA; }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 376 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return BASE; }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 377 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ELEMENTSIZE; }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 378 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SRCREGION; }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 379 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return DSTREGION; }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 380 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return TYPE; }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 383 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SATURATE; }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 384 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALIGN1; }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 385 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALIGN16; }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 386 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SECHALF; }
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 387 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return COMPR; }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 388 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SWITCH; }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 389 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ATOMIC; }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 390 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return NODDCHK; }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 391 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return NODDCLR; }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 392 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return MASK_DISABLE; }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 393 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return MASK_DISABLE; }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 394 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return BREAKPOINT; }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 395 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ACCWRCTRL; }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 396 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return EOT; }
	YY_BREAK
/* extended math functions */
case 201:
YY_RULE_SETUP
#line 399 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_INV; return SIN; }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 400 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_LOG; return LOG; }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 401 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_EXP; return EXP; }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 402 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_SQRT; return SQRT; }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 403 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_RSQ; return RSQ; }
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 404 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_POW; return POW; }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 405 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_SIN; return SIN; }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 406 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_COS; return COS; }
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 407 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_MATH_FUNCTION_SINCOS; return SINCOS; }
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 408 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_MATH_FUNCTION_INT_DIV_QUOTIENT;
	return INTDIV;
}
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 412 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_MATH_FUNCTION_INT_DIV_REMAINDER;
	return INTMOD;
}
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 416 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = BRW_MATH_FUNCTION_INT_DIV_QUOTIENT_AND_REMAINDER;
	return INTDIVMOD;
}
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 421 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SIGNED; }
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 422 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return SCALAR; }
	YY_BREAK
/* predicate control */
case 215:
YY_RULE_SETUP
#line 425 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ANYV; }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 426 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALLV; }
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 427 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ANY2H; }
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 428 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALL2H; }
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 429 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ANY4H; }
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 430 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALL4H; }
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 431 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ANY8H; }
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 432 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALL8H; }
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 433 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ANY16H; }
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 434 "../igt-gpu-tools-2.5/assembler/lex.l"
{ return ALL16H; }
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 436 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_Z; return ZERO; }
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 437 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_Z; return EQUAL; }
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 438 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_NZ; return NOT_ZERO; }
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 439 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_NZ; return NOT_EQUAL; }
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 440 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_G; return GREATER; }
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 441 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_GE; return GREATER_EQUAL; }
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 442 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_L; return LESS; }
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 443 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_LE; return LESS_EQUAL; }
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 444 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_R; return ROUND_INCREMENT; }
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 445 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_O; return OVERFLOW; }
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 446 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yylval.integer = BRW_CONDITIONAL_U; return UNORDERED; }
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 448 "../igt-gpu-tools-2.5/assembler/lex.l"
{
           yylval.string = strdup(yytext);
           return STRING;
}
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 453 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = strtoul(yytext + 2, NULL, 16);
	return INTEGER;
}
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 457 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.integer = strtoul(yytext, NULL, 10);
	return INTEGER;
}
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 462 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	yylval.number = strtod(yytext, NULL);
	return NUMBER;
}
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 467 "../igt-gpu-tools-2.5/assembler/lex.l"
{ } /* eat up whitespace */
	YY_BREAK
case 241:
/* rule 241 can match eol */
YY_RULE_SETUP
#line 469 "../igt-gpu-tools-2.5/assembler/lex.l"
{ yycolumn = 1; }
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 471 "../igt-gpu-tools-2.5/assembler/lex.l"
{
	fprintf(stderr, "%s: %d: %s at \"%s\"\n",
		input_filename, yylineno, "unexpected token", lex_text());
  }
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 475 "../igt-gpu-tools-2.5/assembler/lex.l"
ECHO;
	YY_BREAK
#line 2803 "assembler/intel-gen4asm.p/lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(BLOCK_COMMENT):
case YY_STATE_EOF(CHANNEL):
case YY_STATE_EOF(LINENUMBER):
case YY_STATE_EOF(FILENAME):
case YY_STATE_EOF(REG):
case YY_STATE_EOF(DOTSEL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 679 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 679 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 678);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 475 "../igt-gpu-tools-2.5/assembler/lex.l"


char *
lex_text(void)
{
	return yytext;
  (void) yyunput;
}

#ifndef yywrap
int yywrap() { return 1; }
#endif


